/* Attribute variables */

extern int STDATTR;
extern int HIGHATTR;
extern int BOXATTR;
extern int ACTIVEATTR;
extern int BARSTDATTR;
extern int BARHIGHATTR;
extern int DLGTEXTATTR;
extern int DLGHIGHATTR;
extern int DLGBOXATTR;
extern int DESCATTR;
extern int STATUSBARATTR;
extern int IPSTATATTR;
extern int IPSTATLABELATTR;
extern int PTRATTR;
extern int FIELDATTR;
extern int ERRBOXATTR;
extern int ERRTXTATTR;
extern int ERRRESPATTR;
extern int OSPFATTR;
extern int UDPATTR;
extern int IGPATTR;
extern int IGMPATTR;
extern int IGRPATTR;
extern int ARPATTR;
extern int GREATTR;
extern int UNKNATTR;
